==> org-lsst-ccs-ui-1.2.3-sources.jar: org/lsst/ccs/plugin/jas3/trending/timeselection/PresetsDialog.java <==
package org.lsst.ccs.plugin.jas3.trending.timeselection;

import java.awt.Component;
import java.awt.Window;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JList;
import javax.swing.JOptionPane;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.SwingUtilities;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

/**
 * Dialog for managing time window presets.
 * 
 * @author onoprien
 */
public class PresetsDialog {

// -- Private parts : ----------------------------------------------------------
    
    private final int VSPACE = 5;
    private final int HSPACE = 10;
    
    private final JScrollPane root;
    private final JButton editButton, deleteButton, newButton, okButton;
    private final JTable table;
    
    private final PresetList timeWindowList;
    private TimeSelection selectedTimeWindow;


// -- Construction and initialization : ----------------------------------------
    
    private PresetsDialog(PresetList data) {
        
        timeWindowList = data;
        
        editButton = new JButton("Edit...");
        editButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                TimeSelection ts = getSelectedPreset();
                ts = TimeSelectionPanel.editTimeWindow(editButton, ts);
                if (ts != null) {
                    timeWindowList.insert(ts);
                    setSelectedPreset(ts);
                }
            }
        });
        
        deleteButton = new JButton("Delete");
        deleteButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                TimeSelection ts = getSelectedPreset();
                if (ts != null) timeWindowList.delete(ts);
            }
        });
        
        newButton = new JButton("New...");
        newButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                TimeSelection ts = TimeSelectionPanel.editTimeWindow(newButton, null);
                if (ts != null) {
                    timeWindowList.insert(ts);
                    setSelectedPreset(ts);
                }
            }
        });
        
        okButton = new JButton("  OK  ");
        okButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                selectedTimeWindow = getSelectedPreset();
                Window w = SwingUtilities.getWindowAncestor(okButton);
                if (w != null) w.setVisible(false);
            }
        });
        
        table = new JTable(timeWindowList);
        table.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        table.getSelectionModel().addListSelectionListener(new ListSelectionListener() {
            public void valueChanged(ListSelectionEvent e) {
                TimeSelection ts = getSelectedPreset();
                editButton.setEnabled(ts != null);
                deleteButton.setEnabled(ts != null);
            }
        });
        
        
        root = new JScrollPane(table);
    }
    
// -- Showing the dialog : -----------------------------------------------------
    
    /**
     * Displays the dialog for managing time window presets.
     * 
     * @param parent Parent component.
     * @param data List of presets known to the application.
     * @return Preset selected by the user, or <tt>null</tt> if no preset was selected or if the dialog was canceled.
     */
    static public TimeSelection managePresets(Component parent, PresetList data) {
        PresetsDialog dialog = new PresetsDialog(data);
        int out = JOptionPane.showOptionDialog(parent, dialog.root, "Trending Time Window Presets", 
                       JOptionPane.DEFAULT_OPTION, JOptionPane.PLAIN_MESSAGE, null, 
                       new JButton[] {dialog.editButton, dialog.deleteButton, dialog.newButton, dialog.okButton}, dialog.okButton);
        return dialog.selectedTimeWindow;
    }
    
    
// -- Local methods : ----------------------------------------------------------
    
    private TimeSelection getSelectedPreset() {
        int index = table.getSelectedRow();
        return index == -1 ? null : timeWindowList.get(index);
    }
    
    private void setSelectedPreset(TimeSelection ts) {
        int index = timeWindowList.indexOf(ts);
        if (index == -1) {
            table.getSelectionModel().clearSelection();
        } else {
            table.getSelectionModel().setSelectionInterval(index, index);
        }
    }
}

==> org-lsst-ccs-ui-1.4.2-sources.jar: org/lsst/ccs/plugin/jas3/trending/timeselection/PresetsDialog.java <==
package org.lsst.ccs.plugin.jas3.trending.timeselection;

import java.awt.Component;
import java.awt.Window;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JButton;
import javax.swing.JList;
import javax.swing.JOptionPane;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.SwingUtilities;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

/**
 * Dialog for managing time window presets.
 * 
 * @author onoprien
 */
public class PresetsDialog {

// -- Private parts : ----------------------------------------------------------
    
    private final int VSPACE = 5;
    private final int HSPACE = 10;
    
    private final JScrollPane root;
    private final JButton editButton, deleteButton, newButton, okButton;
    private final JTable table;
    
    private final PresetList timeWindowList;
    private TimeWindow selectedTimeWindow;


// -- Construction and initialization : ----------------------------------------
    
    private PresetsDialog(PresetList data) {
        
        timeWindowList = data;
        
        editButton = new JButton("Edit...");
        editButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                TimeWindow ts = getSelectedPreset();
                ts = TimeWindowPanel.editTimeWindow(editButton, ts);
                if (ts != null) {
                    timeWindowList.insert(ts);
                    setSelectedPreset(ts);
                }
            }
        });
        
        deleteButton = new JButton("Delete");
        deleteButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                TimeWindow ts = getSelectedPreset();
                if (ts != null) timeWindowList.delete(ts);
            }
        });
        
        newButton = new JButton("New...");
        newButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                TimeWindow ts = TimeWindowPanel.editTimeWindow(newButton, null);
                if (ts != null) {
                    timeWindowList.insert(ts);
                    setSelectedPreset(ts);
                }
            }
        });
        
        okButton = new JButton("  OK  ");
        okButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                selectedTimeWindow = getSelectedPreset();
                Window w = SwingUtilities.getWindowAncestor(okButton);
                if (w != null) w.setVisible(false);
            }
        });
        
        table = new JTable(timeWindowList);
        table.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        table.getSelectionModel().addListSelectionListener(new ListSelectionListener() {
            public void valueChanged(ListSelectionEvent e) {
                TimeWindow ts = getSelectedPreset();
                editButton.setEnabled(ts != null);
                deleteButton.setEnabled(ts != null);
            }
        });
        
        
        root = new JScrollPane(table);
    }
    
// -- Showing the dialog : -----------------------------------------------------
    
    /**
     * Displays the dialog for managing time window presets.
     * 
     * @param parent Parent component.
     * @param data List of presets known to the application.
     * @return Preset selected by the user, or <tt>null</tt> if no preset was selected or if the dialog was canceled.
     */
    static public TimeWindow managePresets(Component parent, PresetList data) {
        PresetsDialog dialog = new PresetsDialog(data);
        int out = JOptionPane.showOptionDialog(parent, dialog.root, "Trending Time Window Presets", 
                       JOptionPane.DEFAULT_OPTION, JOptionPane.PLAIN_MESSAGE, null, 
                       new JButton[] {dialog.editButton, dialog.deleteButton, dialog.newButton, dialog.okButton}, dialog.okButton);
        return dialog.selectedTimeWindow;
    }
    
    
// -- Local methods : ----------------------------------------------------------
    
    private TimeWindow getSelectedPreset() {
        int index = table.getSelectedRow();
        return index == -1 ? null : timeWindowList.get(index);
    }
    
    private void setSelectedPreset(TimeWindow ts) {
        int index = timeWindowList.indexOf(ts);
        if (index == -1) {
            table.getSelectionModel().clearSelection();
        } else {
            table.getSelectionModel().setSelectionInterval(index, index);
        }
    }
}
